@@ -8,12 +8,13 @@ use Scalar::Util qw/blessed reftype refaddr/;
 use Data::Dumper;
 use Template;
 use Template::Constants qw/:chomp :debug/;
-use File::ShareDir::ProjectDistDir 1.0 ':all', strict => 1;
+use File::ShareDir qw/dist_dir/;
 use Config;
+use Data::Scan;
 
 # ABSTRACT: Translate an IDL source to an AST
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 
 use Carp qw/carp croak/;
@@ -120,12 +121,11 @@ sub output {
 
 
 sub generate {
-    my ($self, $ast, $template, $targetOptionHashp) = @_;
+  my ($self, $ast, $template, $targetOptionHashp) = @_;
 
     $ast               //= $self->ast();
     $template          //= 'perl5.tt2';
     $targetOptionHashp //= {};
-
     #
     # We provide a default style only if this is a template we know about
     #
@@ -193,7 +193,7 @@ MarpaX::Languages::IDL::AST - Translate an IDL source to an AST
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -330,7 +330,7 @@ lexeme default = action => [ start, length, value ] latm => 1 bless => ::name
 
 :start ::= <specification>
 
-<specification>              ::= <supportedCppCommandAny> <importAny> <definitionMany>
+<specification>              ::= <supportedCppCommandAny> <importAny> <definitionMany> <supportedCppCommandAny>
 <supportedCppCommandAny>     ::= <supportedCppCommand>*
 <supportedCppCommand>        ::= CPPSTYLEDIRECTIVE
 <definition>                 ::= <typeDcl> SEMICOLON
